@@ -1,5 +1,5 @@
 /*
- * $Id: cmdhandler.h 4294 2011-01-13 19:58:29Z jakob $
+ * $Id: cmdhandler.h 5320 2011-07-12 10:42:26Z jakob $
  *
  * Copyright (c) 2009 NLNet Labs. All rights reserved.
  *
@@ -35,7 +35,8 @@
 #define DAEMON_CMDHANDLER_H
 
 #include "config.h"
-#include "scheduler/locks.h"
+#include "shared/allocator.h"
+#include "shared/locks.h"
 
 #include <sys/un.h>
 
@@ -46,9 +47,10 @@ struct engine_struct;
 
 typedef struct cmdhandler_struct cmdhandler_type;
 struct cmdhandler_struct {
+    allocator_type* allocator;
     struct engine_struct* engine;
     struct sockaddr_un listen_addr;
-    se_thread_type thread_id;
+    ods_thread_type thread_id;
     int listen_fd;
     int client_fd;
     int need_to_exit;
@@ -56,11 +58,13 @@ struct cmdhandler_struct {
 
 /**
  * Create command handler.
+ * \param[in] allocator memory allocator
  * \param[in] filename socket file name
- * \return cmdhandler_type* the created command handler
+ * \return cmdhandler_type* created command handler
  *
  */
-cmdhandler_type* cmdhandler_create(const char* filename);
+cmdhandler_type* cmdhandler_create(allocator_type* allocator,
+    const char* filename);
 
 /**
  * Start command handler.
@@ -70,8 +74,8 @@ cmdhandler_type* cmdhandler_create(const char* filename);
 void cmdhandler_start(cmdhandler_type* cmdhandler);
 
 /**
- * Clean up command handler.
- * \param[in] cmdhandler_type* clean up this command handler
+ * Cleanup command handler.
+ * \param[in] cmdhandler_type* command handler
  *
  */
 void cmdhandler_cleanup(cmdhandler_type* cmdhandler);
