@@ -1,5 +1,5 @@
 /*
- * $Id: ods-signer.c 4524 2011-03-03 14:01:47Z matthijs $
+ * $Id: ods-signer.c 5320 2011-07-12 10:42:26Z jakob $
  *
  * Copyright (c) 2009 NLNet Labs. All rights reserved.
  *
@@ -32,9 +32,9 @@
  */
 
 #include "config.h"
-#include "util/file.h"
-#include "util/log.h"
-#include "util/se_malloc.h"
+#include "shared/allocator.h"
+#include "shared/file.h"
+#include "shared/log.h"
 
 #include <errno.h>
 #include <fcntl.h> /* fcntl() */
@@ -52,6 +52,8 @@
 
 #define SE_CLI_CMDLEN 6
 
+static const char* cli_str = "client";
+
 /**
  * Prints usage.
  *
@@ -95,6 +97,7 @@ interface_run(FILE* fp, int sockfd, char* cmd)
     int ret = 0;
     int cmd_written = 0;
     int cmd_response = 0;
+    int written = 0;
     fd_set rset;
     char buf[ODS_SE_MAXLINE];
 
@@ -113,14 +116,14 @@ interface_run(FILE* fp, int sockfd, char* cmd)
             ret = select(maxfdp1, &rset, NULL, NULL, NULL);
             if (ret < 0) {
                 if (errno != EINTR && errno != EWOULDBLOCK) {
-                    se_log_warning("interface select error: %s",
-                        strerror(errno));
+                    ods_log_warning("[%s] interface select error: %s",
+                        cli_str, strerror(errno));
                 }
                 continue;
             }
         } else if (cmd) {
             /* passive mode */
-            se_writen(sockfd, cmd, strlen(cmd));
+            ods_writen(sockfd, cmd, strlen(cmd));
             cmd_written = 1;
             stdineof = 1;
             continue;
@@ -143,41 +146,66 @@ interface_run(FILE* fp, int sockfd, char* cmd)
                 if (n < 0) {
                     /* error occurred */
                     fprintf(stderr, "error: %s\n", strerror(errno));
-                    if (cmd) {
-                        se_free((void*)cmd);
-                    }
                     exit(1);
-                } else if (stdineof == 1) {
-                    /* normal termination */
-                    return;
                 } else {
-                    /* weird termination */
-                    fprintf(stderr, "signer engine terminated "
-                        "prematurely\n");
+                    /* n==0 */
+                    if (stdineof == 1) {
+                        /* normal termination */
+                        return;
+                    } else {
+                        /* weird termination */
+                        fprintf(stderr, "signer engine terminated "
+                                "prematurely\n");
+                        exit(1);
+                    }
+                }
+            }
+
+            if (cmd) {
+                if (n < SE_CLI_CMDLEN) {
+                    /* not enough data received */
+                    fprintf(stderr, "not enough response data received "
+                            "from daemon.\n");
                     exit(1);
                 }
-            }
-
-            if (cmd && strncmp(buf+n-SE_CLI_CMDLEN, "\ncmd> ", SE_CLI_CMDLEN) == 0) {
-                /* we have the full response */
-                if (n > SE_CLI_CMDLEN) {
-                    ret = (int) write(fileno(stdout), buf, n-SE_CLI_CMDLEN);
+                
+                /* n >= SE_CLI_CMDLEN : and so it is safe to do buffer 
+                    manipulations below. */
+                if (strncmp(buf+n-SE_CLI_CMDLEN,"\ncmd> ",SE_CLI_CMDLEN) == 0) {
+                
+                    /* we have the full response */
+                    n -= SE_CLI_CMDLEN;
+                    buf[n] = '\0';
+                    cmd_response = 1;
                 }
-                buf[(n-SE_CLI_CMDLEN)] = '\0';
-                cmd_response = 1;
-                ret = 1;
-            } else {
-                /* we can expect more */
-                ret = (int) write(fileno(stdout), buf, n);
             }
 
-            /* error and shutdown handling */
-            if (ret == 0) {
-                fprintf(stderr, "no write\n");
-            } else if (ret < 0) {
-                fprintf(stderr, "write error: %s\n", strerror(errno));
+            /* n > 0 : when we get to this line... */
+            for (written=0; written < n; written += ret) {
+                /* write what we got to stdout */
+                ret = (int) write(fileno(stdout), &buf[written], n-written);
+                /* error and shutdown handling */
+                if (ret == 0) {
+                    fprintf(stderr, "no write\n");
+                    break;
+                }
+                if (ret < 0) {
+                    if (errno == EINTR || errno == EWOULDBLOCK) {
+                        ret = 0;
+                        continue; /* try again... */
+                    }
+                    fprintf(stderr, "\n\nwrite error: %s\n", strerror(errno));
+                    break;
+                }
+                /* ret > 0 : when we get here... */
+                if (written+ret > n) {
+                    fprintf(stderr, "\n\nwrite error: more bytes (%d) written than required (%d)\n",
+                        written+ret, n);
+                    break;
+                }
+                /* written+ret < n : means partial write, requires us to loop... */
             }
-            if (se_strcmp(buf, ODS_SE_STOP_RESPONSE) == 0 || cmd_response) {
+            if (ods_strcmp(buf, ODS_SE_STOP_RESPONSE) == 0 || cmd_response) {
                 fprintf(stderr, "\n");
                 return;
             }
@@ -193,9 +221,6 @@ interface_run(FILE* fp, int sockfd, char* cmd)
                 if (ret != 0) {
                     fprintf(stderr, "shutdown failed: %s\n",
                         strerror(errno));
-                    if (cmd) {
-                        se_free((void*)cmd);
-                    }
                     exit(1);
                 }
                 FD_CLR(fileno(fp), &rset);
@@ -219,13 +244,15 @@ interface_run(FILE* fp, int sockfd, char* cmd)
                 FD_CLR(fileno(fp), &rset);
                 continue;
             }
+
+            buf[ODS_SE_MAXLINE-1] = '\0';
             if (strncmp(buf, "exit", 4) == 0 ||
                 strncmp(buf, "quit", 4) == 0) {
                 return;
             }
-            se_str_trim(buf);
+            ods_str_trim(buf);
             n = strlen(buf);
-            se_writen(sockfd, buf, n);
+            ods_writen(sockfd, buf, n);
         }
     }
 }
@@ -247,9 +274,6 @@ interface_start(char* cmd)
     if (sockfd <= 0) {
         fprintf(stderr, "Unable to connect to engine. "
             "socket() failed: %s\n", strerror(errno));
-        if (cmd) {
-            se_free((void*)cmd);
-        }
         exit(1);
     }
 
@@ -263,12 +287,12 @@ interface_start(char* cmd)
     ret = connect(sockfd, (const struct sockaddr*) &servaddr,
         sizeof(servaddr));
     if (ret != 0) {
-        if (cmd && se_strcmp(cmd, "start\n") == 0) {
+        if (cmd && ods_strcmp(cmd, "start\n") == 0) {
             ret = system(ODS_SE_ENGINE);
             return;
         }
 
-        if (cmd && se_strcmp(cmd, "running\n") == 0) {
+        if (cmd && ods_strcmp(cmd, "running\n") == 0) {
             fprintf(stderr, "Engine not running.\n");
         } else {
             fprintf(stderr, "Unable to connect to engine: "
@@ -276,24 +300,21 @@ interface_start(char* cmd)
         }
 
         close(sockfd);
-        if (cmd) {
-            se_free((void*)cmd);
-        }
         exit(1);
     }
 
     /* set socket to non-blocking */
     flags = fcntl(sockfd, F_GETFL, 0);
     if (flags < 0) {
-        se_log_error("unable to start interface, fcntl(F_GETFL) "
-            "failed: %s", strerror(errno));
+        ods_log_error("[%s] unable to start interface, fcntl(F_GETFL) "
+            "failed: %s", cli_str, strerror(errno));
         close(sockfd);
         return;
     }
     flags |= O_NONBLOCK;
     if (fcntl(sockfd, F_SETFL, flags) < 0) {
-        se_log_error("Unable to start interface, fcntl(F_SETFL) "
-            "failed: %s", strerror(errno));
+        ods_log_error("[%s] unable to start interface, fcntl(F_SETFL) "
+            "failed: %s", cli_str, strerror(errno));
         close(sockfd);
         return;
     }
@@ -301,15 +322,15 @@ interface_start(char* cmd)
     /* set stdin to non-blocking */
     flags = fcntl(fileno(stdin), F_GETFL, 0);
     if (flags < 0) {
-        se_log_error("Unable to start interface, fcntl(F_GETFL) "
-            "failed: %s", strerror(errno));
+        ods_log_error("[%s] unable to start interface, fcntl(F_GETFL) "
+            "failed: %s", cli_str, strerror(errno));
         close(sockfd);
         return;
     }
     flags |= O_NONBLOCK;
     if (fcntl(fileno(stdin), F_SETFL, flags) < 0) {
-        se_log_error("Unable to start interface, fcntl(F_SETFL) "
-            "failed: %s", strerror(errno));
+        ods_log_error("[%s] unable to start interface, fcntl(F_SETFL) "
+            "failed: %s", cli_str, strerror(errno));
         close(sockfd);
         return;
     }
@@ -320,7 +341,7 @@ interface_start(char* cmd)
     }
 
     /* run */
-    se_log_init(NULL, 0, 0);
+    ods_log_init(NULL, 0, 0);
     interface_run(stdin, sockfd, cmd);
     close(sockfd);
     return;
@@ -338,6 +359,11 @@ main(int argc, char* argv[])
     int options_size = 0;
     const char* options[4];
     char* cmd = NULL;
+    allocator_type* clialloc = allocator_create(malloc, free);
+    if (!clialloc) {
+        fprintf(stderr,"error, malloc failed for client\n");
+        exit(1);
+    }
 
     if (argc > 3) {
         fprintf(stderr,"error, too many arguments\n");
@@ -352,7 +378,11 @@ main(int argc, char* argv[])
         }
     }
     if (argc > 1) {
-        cmd = (char*) se_calloc(options_size+2,sizeof(char));
+        cmd = (char*) allocator_alloc(clialloc, (options_size+2)*sizeof(char));
+        if (!cmd) {
+            fprintf(stderr, "memory allocation failed\n");
+            exit(1);
+        }
         (void)strncpy(cmd, "", 1);
         for (c = 1; c < argc; c++) {
             (void)strncat(cmd, options[c], strlen(options[c]));
@@ -362,19 +392,16 @@ main(int argc, char* argv[])
     }
 
     /* main stuff */
-    if (cmd && se_strcmp(cmd, "-h\n") == 0) {
+    if (cmd && ods_strcmp(cmd, "-h\n") == 0) {
         usage(stdout);
-        return 0;
-    } else if (cmd && se_strcmp(cmd, "--help\n") == 0) {
+    } else if (cmd && ods_strcmp(cmd, "--help\n") == 0) {
         usage(stdout);
-        return 0;
+    } else {
+        interface_start(cmd);
     }
 
-    interface_start(cmd);
-
     /* done */
-    if (cmd) {
-        se_free((void*)cmd);
-    }
+    allocator_deallocate(clialloc, (void*) cmd);
+    allocator_cleanup(clialloc);
     return 0;
 }
