@@ -1,5 +1,5 @@
 /*
- * $Id: domain.h 4523 2011-03-03 12:48:18Z matthijs $
+ * $Id: domain.h 5320 2011-07-12 10:42:26Z jakob $
  *
  * Copyright (c) 2009 NLNet Labs. All rights reserved.
  *
@@ -35,26 +35,27 @@
 #define SIGNER_DOMAIN_H
 
 #include "config.h"
+#include "daemon/worker.h"
+#include "scheduler/fifoq.h"
+#include "shared/allocator.h"
+#include "shared/status.h"
 #include "signer/denial.h"
-#include "signer/hsm.h"
-#include "signer/nsec3params.h"
+#include "signer/keys.h"
 #include "signer/rrset.h"
-#include "signer/signconf.h"
-#include "signer/stats.h"
 
 #include <ldns/ldns.h>
 #include <time.h>
 
-#define DOMAIN_STATUS_NONE      0 /* initial domain status */
-#define DOMAIN_STATUS_APEX      1 /* apex of the zone */
-#define DOMAIN_STATUS_AUTH      2 /* authoritative domain */
-#define DOMAIN_STATUS_NS        3 /* unsigned delegation */
-#define DOMAIN_STATUS_DS        4 /* signed delegation */
-#define DOMAIN_STATUS_ENT_AUTH  5 /* empty non-terminal to authoritative data */
-#define DOMAIN_STATUS_ENT_NS    6 /* empty non-terminal to unsigned delegation */
-#define DOMAIN_STATUS_ENT_GLUE  7 /* empty non-terminal to occluded data */
-#define DOMAIN_STATUS_OCCLUDED  8 /* occluded data (glue) */
-#define DOMAIN_STATUS_HASH      9 /* hashed domain */
+enum domain_status_enum {
+    DOMAIN_STATUS_NONE = 0, /* initial domain status [UNSIGNED] */
+    DOMAIN_STATUS_APEX,     /* apex domain, authoritative [SIGNED] */
+    DOMAIN_STATUS_AUTH,     /* authoritative domain, non-apex [SIGNED] */
+    DOMAIN_STATUS_NS,       /* unsigned delegation [UNSIGNED] */
+    DOMAIN_STATUS_DS,       /* signed delegation [SIGNED] */
+    DOMAIN_STATUS_ENT,      /* empty non-terminal [UNSIGNED] */
+    DOMAIN_STATUS_OCCLUDED  /* occluded domain [UNSIGNED] */
+};
+typedef enum domain_status_enum domain_status;
 
 #define SE_NSEC_RDATA_NXT          0
 #define SE_NSEC_RDATA_BITMAP       1
@@ -68,16 +69,19 @@
  */
 typedef struct domain_struct domain_type;
 struct domain_struct {
-    ldns_rdf* name;
+    /* General domain info */
+    ldns_rdf* dname;
+    domain_status dstatus;
+    allocator_type* allocator;
+
+    /* Family */
     domain_type* parent;
+
+    /* Denial of Existence */
     denial_type* denial;
+
+    /* RRsets */
     ldns_rbtree_t* rrsets;
-    size_t subdomain_count;
-    size_t subdomain_auth;
-    int domain_status;
-    int initialized;
-    uint32_t internal_serial;
-    uint32_t outbound_serial;
 };
 
 /**
@@ -90,50 +94,84 @@ domain_type* domain_create(ldns_rdf* dname);
 
 /**
  * Recover domain from backup.
- * \param[in] fd backup file descriptor
- * \param[out] curnxt if denial nxt changed
- * \param[out] curbm if denial bitmap changed
- * \return domain_type* recovered domain
- *
- */
-domain_type* domain_recover_from_backup(FILE* fd, int* curnxt, int* curbm);
-
-/**
- * Lookup a RRset within the domain.
  * \param[in] domain domain
- * \param[in] type RRtype to look for
- * \return rrset_type* RRset if found
+ * \param[in] fd backup file descriptor
+ * \param[in] dstatus domain status
+ * \return ods_status status
  *
  */
-rrset_type* domain_lookup_rrset(domain_type* domain, ldns_rr_type type);
+ods_status domain_recover(domain_type* domain, FILE* fd,
+    domain_status dstatus);
 
 /**
- * Add a RRset to the domain.
+ * Recover RR from backup.
+ * \param[in] domain domain
+ * \param[in] rr RR
+ * \return int 0 on success, 1 on error
+ *
+ */
+/*
+int domain_recover_rr_from_backup(domain_type* domain, ldns_rr* rr);
+*/
+
+/**
+ * Recover RRSIG from backup.
+ * \param[in] domain domain
+ * \param[in] rrsig RRSIG
+ * \param[in] type_covered RRtype that is covered by rrsig
+ * \param[in] locator key locator
+ * \param[in] flags key flags
+ * \return int 0 on success, 1 on error
+ *
+ */
+/*
+int domain_recover_rrsig_from_backup(domain_type* domain, ldns_rr* rrsig,
+    ldns_rr_type type_covered, const char* locator, uint32_t flags);
+*/
+
+/**
+ * Count the number of RRsets at this domain.
+ * \param[in] domain domain
+ * \return size_t number of RRsets
+ *
+ */
+size_t domain_count_rrset(domain_type* domain);
+
+/**
+ * Look up RRset at this domain.
+ * \param[in] domain the domain
+ * \param[in] rrtype RRtype
+ * \return rrset_type* RRset, if found
+ *
+ */
+rrset_type* domain_lookup_rrset(domain_type* domain, ldns_rr_type rrtype);
+
+/**
+ * Add RRset to domain.
  * \param[in] domain domain
  * \param[in] rrset RRset
- * \param[in] recover if true, don't update domain status
  * \return rrset_type* added RRset
  *
  */
-rrset_type* domain_add_rrset(domain_type* domain, rrset_type* rrset, int recover);
+rrset_type* domain_add_rrset(domain_type* domain, rrset_type* rrset);
 
 /**
- * Delete a RRset from the domain.
+ * Delete RRset from domain.
  * \param[in] domain domain
  * \param[in] rrset RRset
- * \param[in] recover if true, don't update domain status
  * \return rrset_type* RRset if failed
  *
  */
-rrset_type* domain_del_rrset(domain_type* domain, rrset_type* rrset, int recover);
+rrset_type* domain_del_rrset(domain_type* domain, rrset_type* rrset);
 
 /**
- * Return the number of RRsets at this domain.
- * \param[in] domain domain
- * \return int number of RRsets at domain
+ * Calculate differences at this domain between current and new RRsets.
+ * \param[in] domain the domain
+ * \param[in] kl current key list
+ * \return ods_status status
  *
  */
-int domain_count_rrset(domain_type* domain);
+ods_status domain_diff(domain_type* domain, keylist_type* kl);
 
 /**
  * Examine domain and verify if data exists.
@@ -150,7 +188,7 @@ int domain_examine_data_exists(domain_type* domain, ldns_rr_type rrtype,
  * Examine domain NS RRset and verify its RDATA.
  * \param[in] domain domain
  * \param[in] nsdname domain name that should match one of the NS RDATA
- * \return int 0 if nsdname exists as NS RDATA, 1 otherwise
+ * \return int 1 if match, 0 otherwise
  *
  */
 int domain_examine_ns_rdata(domain_type* domain, ldns_rdf* nsdname);
@@ -158,7 +196,7 @@ int domain_examine_ns_rdata(domain_type* domain, ldns_rdf* nsdname);
 /**
  * Examine domain and verify if it is a valid zonecut (or no NS RRs).
  * \param[in] domain domain
- * \retun int 0 if the RRset is a valid zonecut (or no zonecut), 1 otherwise
+ * \retun int 1 if the RRset is a valid zonecut (or no zonecut), 0 otherwise
  *
  */
 int domain_examine_valid_zonecut(domain_type* domain);
@@ -167,7 +205,7 @@ int domain_examine_valid_zonecut(domain_type* domain);
  * Examine domain and verify if there is no other data next to a RRset.
  * \param[in] domain domain
  * \param[in] rrtype RRtype
- * \retun int 0 if the RRset is alone, 1 otherwise
+ * \return int 1 if the RRset is alone, 0 otherwise
  *
  */
 int domain_examine_rrset_is_alone(domain_type* domain, ldns_rr_type rrtype);
@@ -176,96 +214,43 @@ int domain_examine_rrset_is_alone(domain_type* domain, ldns_rr_type rrtype);
  * Examine domain and verify if the RRset is a singleton.
  * \param[in] domain domain
  * \param[in] rrtype RRtype
- * \retun int 0 if the RRset is a singleton, 1 otherwise
+ * \return int 1 if the RRset is a singleton, 0 otherwise
  *
  */
 int domain_examine_rrset_is_singleton(domain_type* domain, ldns_rr_type rrtype);
 
 /**
- * Update domain with pending changes.
- * \param[in] domain domain
- * \param[in] serial version to update to
- * \return int 0 on success, 1 on error
+ * Commit updates to domain.
+ * \param[in] domain the domain
+ * \return ods_status status
  *
  */
-int domain_update(domain_type* domain, uint32_t serial);
+ods_status domain_commit(domain_type* domain);
 
 /**
- * Cancel update.
- * \param[in] domain domain
+ * Rollback updates from domain.
+ * \param[in] domain the domain
  *
  */
-void domain_cancel_update(domain_type* domain);
+void domain_rollback(domain_type* domain);
 
 /**
- * Update domain status.
- * \param[in] domain domain
+ * Set domain status.
+ * \param[in] domain the domain
  *
  */
-void domain_update_status(domain_type* domain);
+void domain_dstatus(domain_type* domain);
 
 /**
- * Sign domain.
- * \param[in] ctx HSM context
- * \param[in] domain domain
- * \param[in] owner owner of the zone
- * \param[in] sc sign configuration
- * \param[in] signtime time zone is being signed
- * \param[in] serial outbound serial
- * \param[out] stats update statistics
- * \return int 0 on success, 1 on error
+ * Queue all RRsets at this domain.
+ * \param[in] domain the domain
+ * \param[in] q queue
+ * \param[in] worker owner of data
+ * \return ods_status status
  *
  */
-int domain_sign(hsm_ctx_t* ctx, domain_type* domain, ldns_rdf* owner,
-    signconf_type* sc, time_t signtime, uint32_t serial, stats_type* stats);
-
-/**
- * Add RR to domain.
- * \param[in] domain domain
- * \param[in] rr RR
- * \return int 0 on success, 1 on error
- *
- */
-int domain_add_rr(domain_type* domain, ldns_rr* rr);
-
-/**
- * Recover RR from backup.
- * \param[in] domain domain
- * \param[in] rr RR
- * \return int 0 on success, 1 on error
- *
- */
-int domain_recover_rr_from_backup(domain_type* domain, ldns_rr* rr);
-
-/**
- * Recover RRSIG from backup.
- * \param[in] domain domain
- * \param[in] rrsig RRSIG
- * \param[in] type_covered RRtype that is covered by rrsig
- * \param[in] locator key locator
- * \param[in] flags key flags
- * \return int 0 on success, 1 on error
- *
- */
-int domain_recover_rrsig_from_backup(domain_type* domain, ldns_rr* rrsig,
-    ldns_rr_type type_covered, const char* locator, uint32_t flags);
-
-/**
- * Delete RR from domain.
- * \param[in] domain domain
- * \param[in] rr RR
- * \return int 0 on success, 1 on error
- *
- */
-int domain_del_rr(domain_type* domain, ldns_rr* rr);
-
-/**
- * Delete all RRs from domain.
- * \param[in] domain domain
- * \return int 0 on success, 1 on error
- *
- */
-int domain_del_rrs(domain_type* domain);
+ods_status domain_queue(domain_type* domain, fifoq_type* q,
+    worker_type* worker);
 
 /**
  * Clean up domain.
@@ -276,26 +261,18 @@ void domain_cleanup(domain_type* domain);
 
 /**
  * Print domain.
- * \param[in] out file descriptor
- * \param[in] domain domain to print
+ * \param[in] fd file descriptor
+ * \param[in] domain domain
  *
  */
 void domain_print(FILE* fd, domain_type* domain);
 
 /**
- * Print NSEC(3)s at domain.
- * \param[in] out file descriptor
- * \param[in] domain domain to print
+ * Backup domain.
+ * \param[in] fd file descriptor
+ * \param[in] domain domain
  *
  */
-void domain_print_nsec(FILE* fd, domain_type* domain);
-
-/**
- * Print RRSIGs at domain.
- * \param[in] out file descriptor
- * \param[in] domain domain to print
- *
- */
-void domain_print_rrsig(FILE* fd, domain_type* domain);
+void domain_backup(FILE* fd, domain_type* domain);
 
 #endif /* SIGNER_DOMAIN_H */
